<p align="center">
    <a href="https://splidejs.com" target="_blank">
        <img width="80" src="images/logo.svg">
    </a>
    <a href="https://vuejs.org/" target="_blank">
        <img width="80" src="images/vue-logo.svg">
    </a>
</p>

# Vue Splide
Vue Splide is the [Vue](https://vuejs.org/) component for the [Splide](https://github.com/Splidejs/splide) slider/carousel library.
* [Splide Demos](https://splidejs.com/)

This component requires **Vue 3**. For Vue 2, use the old version (0.3.5).

## Notice
- Updated to Splide v3 and Vue 3.
- The usage is (almost) same but documents will be revised soon

## Migration
The `controls` slot is renamed to `after-track`.

## Installation
Get the latest version by NPM:
```bash
$ npm install @splidejs/vue-splide
```

## Registration
### Global Registration
Import `vue-splide` and install it into your app.
```ts
import { createApp } from 'vue';
import App from './App.vue';
import VueSplide from '@splidejs/vue-splide';

const app = createApp( App );
app.use( VueSplide );
app.mount( '#app' );
```

### Local Registration
Import `Splide` and `SplideSlide` components:
```ts
import { Splide, SplideSlide } from '@splidejs/vue-splide';

export default defineComponent( {
  components: {
    Splide,
    SplideSlide,
  },
} );
```

### CSS
Import [styles](https://splidejs.com/themes/) if you need.
```javascript
import '@splidejs/splide/dist/css/themes/splide-default.min.css';
// or
import '@splidejs/splide/dist/css/themes/splide-sea-green.min.css';
// or
import '@splidejs/splide/dist/css/themes/splide-skyblue.min.css';
```

## Options and Props
The `Splide` component accepts [options](https://splidejs.com/options/) as an object:
```vue
<splide :options="yourOptions"></splide>
```
Also, you can pass extensions or transition as props.
```vue
<splide
  :extensions="yourExtensions"
  :transition="yourTransition"
>
</splide>
```
See this [document](https://splidejs.com/integration-vue-splide) for more details.

## Listening to Events
You can listen to all [Splide events](https://splidejs.com/events/) through the `Splide` component. The callback function name is generated by the original event name, adding a "splide:" prefix. For example, "arrow:mounted" will be "splide:arrow:mounted".
```vue
<splide @splide:arrow:mounted="onArrowMounted"></splide>
```
Note that the first argument is the splide instance, meaning original arguments are shifted by one.

## Examples
Here is a small example:
```vue
<template>
  <splide :options="options">
    <splide-slide>
      <img src="image1.jpg">
    </splide-slide>
    <splide-slide>
      <img src="image2.jpg">
    </splide-slide>
    <splide-slide>
      <img src="image3.jpg">
    </splide-slide>
  </splide>
</template>

<script>
import { defineComponent } from 'vue';

export default defineComponent( {
  setup() {
    const options = {
      rewind: true,
      gao   : '1rem',
    };

    return { options }
  },
} );
</script>
```

## License
Vue Splide and Splide are released under the MIT license.
© 2021 Naotoshi Fujita
